@@ -29,6 +29,10 @@ public:
     virtual ~InputMethodManager();
 
     void load();
+    void load(const std::function<void(InputMethodManager &)>
+                  &buildDefaultGroupCallback);
+    void reset(const std::function<void(InputMethodManager &)>
+                   &buildDefaultGroupCallback);
     void save();
 
     std::vector<std::string> groups() const;
@@ -41,6 +45,8 @@ public:
     void addEmptyGroup(const std::string &name);
     void removeGroup(const std::string &name);
 
+    void setGroupOrder(const std::vector<std::string> &groups);
+
     const InputMethodEntry *entry(const std::string &name) const;
     bool foreachEntries(
         const std::function<bool(const InputMethodEntry &entry)> callback);
@@ -51,10 +57,6 @@ public:
                          void(const std::string &group));
 
 private:
-    void loadConfig();
-    void buildDefaultGroup();
-    void setGroupOrder(const std::vector<std::string> &groups);
-
     std::unique_ptr<InputMethodManagerPrivate> d_ptr;
     FCITX_DECLARE_PRIVATE(InputMethodManager);
 };
